<!-- badges: start -->
[![CRANStatusBadge](http://www.r-pkg.org/badges/version/fBasics)](https://cran.r-project.org/package=fBasics)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/fBasics)](https://www.r-pkg.org/pkg/fBasics)
[![CRAN RStudio mirror downloads](https://cranlogs.r-pkg.org/badges/grand-total/fBasics?color=blue)](https://r-pkg.org/pkg/fBasics)
<!-- badges: end -->


The R package 'fBasics' provides a collection of functions to explore and to
investigate basic properties of financial returns and related quantities.  The
covered fields include techniques of explorative data analysis and the
investigation of distributional properties, including parameter estimation and
hypothesis testing. Even more there are several utility functions for data
handling and management.

Package `fBasics` is part of the Rmetrics suite of R packages and is developed on R-forge at
[fBasics](https://r-forge.r-project.org/scm/viewvc.php/pkg/fBasics/?root=rmetrics).
The root of Rmetrics is at [R-forge](https://r-forge.r-project.org/projects/rmetrics).


# Installing fBasics


Install the [latest stable version](https://cran.r-project.org/package=fBasics) of
`fBasics` from CRAN:

    install.packages("fBasics")


You can install the
[development version](https://r-forge.r-project.org/scm/viewvc.php/pkg/fBasics/?root=rmetrics)
of `fBasics` from R-forge:

    install.packages("fBasics", repos = "http://R-Forge.R-project.org")

To report bugs visit [Rmetrics](https://r-forge.r-project.org/projects/rmetrics/).

# Documentation

You can view the documentation of `fBasics` at
[fBasicsDoc](https://geobosh.github.io/fBasicsDoc/)
or download the
[reference manual](https://cran.r-project.org/package=fBasics/fBasics.pdf)
of the latest release from CRAN.
